require "util" -- for table.deepcopy

local g = require "graphics" -- for modded unit


local function setNameDurationCD(base, name, durationCD)
  local turret = table.deepcopy(base)
  turret.name = name
  turret.attack_parameters.cooldown = durationCD
  turret.attack_parameters.ammo_type.action.action_delivery.duration = durationCD
  return turret
end

local function setNameDrawAsProperty(base, name, property, value)
  local turret = table.deepcopy(base)
  turret.name = name
  
  if value == nil then
    value = true
  end
  
  -- Override whatever value was defined in the make graphic function
  turret.energy_glow_animation.draw_as_glow = false
  turret.energy_glow_animation[property] = value
  turret.energy_glow_animation.hr_version[property] = value
      
  return turret
end

local function makeItem(name)
  local item = table.deepcopy(data.raw["item"]["laser-turret"])
  item.name = name
  item.place_result = name
  return item
end


------------------------------------------------------------------------------
-- Base Game Entities
------------------------------------------------------------------------------

local baseTurret = data.raw["electric-turret"]["laser-turret"]
local baseCooldown = baseTurret.attack_parameters.cooldown
-- baseTurret.attack_parameters.ammo_type.action.action_delivery.duration is same as cooldown by default

data:extend{setNameDurationCD(baseTurret,  "tenX",  baseCooldown * 10)}

data:extend{setNameDrawAsProperty(baseTurret, "drawAsGlow",   "draw_as_glow")}
data:extend{setNameDrawAsProperty(baseTurret, "drawAsLight",  "draw_as_light")}
data:extend{setNameDrawAsProperty(baseTurret, "drawAsShadow", "draw_as_shadow")}


data:extend{makeItem("tenX")}            
data:extend{makeItem("drawAsGlow")}
data:extend{makeItem("drawAsLight")}
data:extend{makeItem("drawAsShadow")}


data.raw["radar"]["radar"].max_health = 999999


------------------------------------------------------------------------------
-- My Mod Entities
------------------------------------------------------------------------------


local m_dag = table.deepcopy(data.raw["electric-turret"]["laser-turret"])
m_dag.name = "Mod_DrawAsGlow"
m_dag.shoot_in_prepare_state = true
m_dag.folded_animation      = g.headAnimation
m_dag.prepared_animation    = g.headAnimation
m_dag.energy_glow_animation = g.glowAnimation
m_dag.glow_light_intensity = 1.0
m_dag.preparing_animation = nil
m_dag.folding_animation   = nil
m_dag.attacking_animation = nil


data:extend{m_dag}
data:extend{setNameDrawAsProperty(table.deepcopy(m_dag), "Mod_DrawAsNormal", "draw_as_glow", false)}
data:extend{setNameDrawAsProperty(table.deepcopy(m_dag), "Mod_DrawAsShadow", "draw_as_shadow")}
data:extend{setNameDrawAsProperty(table.deepcopy(m_dag), "Mod_DrawAsLight",  "draw_as_light")}


data:extend{makeItem("Mod_DrawAsGlow")}
data:extend{makeItem("Mod_DrawAsNormal")}
data:extend{makeItem("Mod_DrawAsShadow")}
data:extend{makeItem("Mod_DrawAsLight")}
